@@ -1,6 +1,6 @@
 package re::engine::GNU;
 use strict;
-use diagnostics;
+use warnings FATAL => 'all';
 use 5.010000;
 use XSLoader ();
 
@@ -12,7 +12,7 @@ our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 our @ISA = 'Regexp';
 
 BEGIN {
-    our $VERSION = '0.015'; # VERSION
+    our $VERSION = '0.016'; # VERSION
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -102,7 +102,7 @@ re::engine::GNU - GNU Regular Expression Engine
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
